<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 02/28/2009 *
 * ===================                          Last change: 02/28/2009 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : session-functions.php                            *
 * -------------------------------------------------------------------- *
 * Short description : Session-relevant functions                       *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Sitzungsrelevante Funktionen                     *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2011 by Mailer Developer Team                   *
 * For more information visit: http://www.mxchange.org                  *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	die();
}

// Unset/set session variables
function setSession ($var, $value) {
	// Abort in CSS mode here
	if (isCssOutputMode()) return true;

	// Trim value and session variable
	$var   = trim(secureString($var));
	$value = trim($value);

	// Is the session variable set?
	if (('' . $value . '' == '') && (isSessionVariableSet($var))) {
		// Remove the session
		//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'UNSET:' . $var . '=' . getSession($var));
		unset($GLOBALS['_SESSION'][$var]);
		if (phpversion() >= '5.3.1') {
			// session_unregister() is deprecated as of 5.3.1
			return true;
		} else {
			// PHP version < 5.3.1
			return session_unregister($var);
		}
	} elseif (('' . $value . '' != '') && (!isSessionVariableSet($var))) {
		// Set session
		//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'SET:' . $var . '=' . $value);
		$GLOBALS['_SESSION'][$var] =  $value;
		if (phpversion() >= '5.3.1') {
			// session_unregister() is deprecated as of 5.3.1
			return true;
		} else {
			// PHP version < 5.3.1
			return session_register($var);
		}
	} elseif (!empty($value)) {
		// Update session
		//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'UPDATE:' . $var . '=' . $value);
		$GLOBALS['_SESSION'][$var] = $value;
		return true;
	}

	// Ignored (but valid)
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'IGNORED:' . $var . '=' . $value);
	return true;
}

// Check wether a session variable is set
function isSessionVariableSet ($var) {
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'var=' . $var . ' set in session');
	return (isset($GLOBALS['_SESSION'][$var]));
}

// Returns wether the value of the session variable or NULL if not set
function getSession ($var) {
	// Default is not found ;-)
	$value = null;

	// Is the variable there?
	if (isSessionVariableSet($var)) {
		// Then  get it secured!
		$value = SQL_ESCAPE($GLOBALS['_SESSION'][$var]);
	} // END - if

	// Return the value
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, $var . '=' . $value);
	return $value;
}

// Destroy user session
function destroyMemberSession () {
	// Reset userid
	initMemberId();

	// Remove all user data from session
	return ((setSession('userid', '')) && (setSession('u_hash', '')));
}

// Destroys the admin session
function destroyAdminSession ($destroy = true) {
	// Kill maybe existing session variables including array elements
	setAdminId(0);
	setAdminMd5('');
	setAdminLast('');

	// Destroy session if requested and return status
	if ($destroy === true) {
		return session_destroy();
	} // END - if

	// All fine if we shall not really destroy the session
	return true;
}

// [EOF]
?>
